@@ -1,6 +1,6 @@
 /*
  *
- * $Id: k3bcdrecordwriter.cpp,v 1.30.2.7 2004/05/07 16:39:22 trueg Exp $
+ * $Id: k3bcdrecordwriter.cpp,v 1.30.2.8 2004/07/15 19:24:56 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -183,7 +183,17 @@ void K3bCdrecordWriter::prepareProcess()
     }
   }
   else if( m_writingMode == K3b::RAW ) {
-    *m_process << "-raw";
+    if( burnDevice()->supportsWriteMode( K3bCdDevice::CdDevice::RAW_R96R ) )
+      *m_process << "-raw96r";
+    else if( burnDevice()->supportsWriteMode( K3bCdDevice::CdDevice::RAW_R16 ) )
+      *m_process << "-raw16";
+    else if( burnDevice()->supportsWriteMode( K3bCdDevice::CdDevice::RAW_R96P ) )
+      *m_process << "-raw96p";
+    else {
+      emit infoMessage( i18n("Writer does not support raw writing."), WARNING );
+      if( m_cdrecordBinObject->hasFeature( "tao" ) )
+	*m_process << "-tao";
+    }
   }
   else if( m_cdrecordBinObject->hasFeature( "tao" ) )
     *m_process << "-tao";
