@@ -1,6 +1,6 @@
 /* 
  *
- * $Id: k3blistview.cpp,v 1.16.2.2 2004/06/03 08:29:22 trueg Exp $
+ * $Id: k3blistview.cpp,v 1.16.2.4 2004/08/03 11:34:28 trueg Exp $
  * Copyright (C) 2003 Sebastian Trueg <trueg@k3b.org>
  *
  * This file is part of the K3b project.
@@ -378,12 +378,6 @@ void K3bListViewItem::paintProgressBar( QPainter* p, const QColorGroup& cgh, int
   // the QPainter is translated so 0, m_vMargin is the upper left of our paint rect
   QRect r( 0, m_vMargin, width, height()-2*m_vMargin );
 
-  // we want a little additional margin
-  r.setLeft( r.left()+1 );
-  r.setWidth( r.width()-2 );
-  r.setTop( r.top()+1 );
-  r.setHeight( r.height()-2 );
-
   // create the double buffer pixmap
   static QPixmap *doubleBuffer = 0;
   if( !doubleBuffer )
@@ -399,6 +393,12 @@ void K3bListViewItem::paintProgressBar( QPainter* p, const QColorGroup& cgh, int
     dbPainter.fillRect( 0, 0, width, height(), 
 			cgh.brush( QPalette::backgroundRoleFromMode(listView()->viewport()->backgroundMode()) ) );
 
+  // we want a little additional margin
+  r.setLeft( r.left()+1 );
+  r.setWidth( r.width()-2 );
+  r.setTop( r.top()+1 );
+  r.setHeight( r.height()-2 );
+
   // this might be a stupid hack but most styles do not reimplement drawPrimitive PE_ProgressBarChunk
   // so this way the user is happy....
   static QProgressBar* s_dummyProgressBar = 0;
@@ -678,18 +678,7 @@ void K3bListView::setCurrentItem( QListViewItem* i )
   if( !i || i == currentItem() )
     return;
 
-  if( m_currentEditItem )
-    if( m_currentEditItem->editorType(m_currentEditColumn) == K3bListViewItem::LINE ) {
-      if( m_editorLineEdit->validator() ) {
-	QString str = m_editorLineEdit->text();
-	int pos = 0;
-	if( m_editorLineEdit->validator()->validate( str, pos ) == QValidator::Acceptable )
-	  slotEditorLineEditReturnPressed();
-      }
-      else
-	slotEditorLineEditReturnPressed();
-    }
-
+  doRename();
   hideEditor();
   m_currentEditItem = 0;
   KListView::setCurrentItem( i );
@@ -897,18 +886,47 @@ bool K3bListView::eventFilter( QObject* o, QEvent* e )
 {
   if( e->type() == QEvent::KeyPress ) { 
      QKeyEvent* ke = static_cast<QKeyEvent*>(e);
-     if( ke->key() == Key_Return ) {
-       doRename();
+     if( ke->key() == Key_Tab ) {
        if( o == m_editorLineEdit || o == m_editorMsfEdit || o == m_editorSpinBox ) {
+	 doRename();
+
+	 if( m_currentEditItem ) {
+	   // can we rename one of the other columns?
+	   int col = currentEditColumn()+1;
+	   while( col < columns() && m_currentEditItem->editorType( col ) == K3bListViewItem::NONE )
+	     ++col;
+	   if( col < columns() )
+	     editItem( m_currentEditItem, col );
+	   else if( K3bListViewItem* nextItem = dynamic_cast<K3bListViewItem*>( m_currentEditItem->nextSibling() ) ) {
+	     // edit first column
+	     col = 0;
+	     while( col < columns() && nextItem->editorType( col ) == K3bListViewItem::NONE )
+	       ++col;
+	     editItem( nextItem, col );
+	   }
+	   else
+	     hideEditor();
+	 }
+
+	 return true;
+       }
+     }
+     if( ke->key() == Key_Return ) {
+       if( o == m_editorLineEdit || o == m_editorMsfEdit || o == m_editorSpinBox ) {
+	 doRename();
 	 if( K3bListViewItem* nextItem = dynamic_cast<K3bListViewItem*>( m_currentEditItem->nextSibling() ) )
 	   editItem( nextItem, currentEditColumn() );
 	 else
 	   hideEditor();
+
+	 return true;
        }
      }
      else if( ke->key() == Key_Escape ) {
        if( o == m_editorLineEdit || o == m_editorSpinBox || o == m_editorMsfEdit )
 	 hideEditor();
+
+       return true;
      }
   }
   else if( e->type() == QEvent::FocusOut ) {
